@@ -13,6 +13,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+# flake8: noqa
 """Top-level package for chartify."""
 from chartify._core.chart import Chart
 from chartify._core.radar_chart import RadarChart
@@ -21,8 +22,8 @@ from chartify._core.options import options
 from chartify import examples
 
 __author__ = """Chris Halpert"""
-__email__ = 'chalpert@spotify.com'
-__version__ = '3.0.4'
+__email__ = "chalpert@spotify.com"
+__version__ = "4.0.0"
 
 _IPYTHON_INSTANCE = False
 
@@ -44,7 +45,7 @@ def set_display_settings():
             if curstate().notebook_type is None:
                 # Inline resources uses bokeh.js from the local version.
                 # This enables offline usage.
-                output_notebook(Resources('inline'), hide_banner=True)
+                output_notebook(Resources("inline"), hide_banner=True)
 
 
 set_display_settings()
